function mod = init1

    % Two vessels with equal non-dimensional parameters to a mariner class
    % vessel

    addpath(genpath('../gnc'));

    l1 = 200;       w1 = 30;
    l2 = 40;        w2 = 16;
    rp1 = [-100, -10]';
    rp2 = [20, -5]';

    delta = 10/180*pi;

    %From vts2d script
            m  = 798e-5;
            Iz = 39.2e-5;
    %       xG = -0.023;

            Xudot =  -42e-5;   Yvdot =  -748e-5;   Nvdot = 4.646e-5;
            Xu    = -184e-5;   Yrdot =-9.354e-5;   Nrdot = -43.8e-5;
            Xuu   = -110e-5;   Yv    = -1160e-5;   Nv    =  -264e-5;
            Xuuu  = -215e-5;   Yr    =  -499e-5;   Nr    =  -166e-5;
            Xvv   = -899e-5;   Yvvv  = -8078e-5;   Nvvv  =  1636e-5;
            Xrr   =   18e-5;   Yvvr  = 15356e-5;   Nvvr  = -5483e-5;
            Xdd   =  -95e-5;   Yvu   = -1160e-5;   Nvu   =  -264e-5;
            Xudd  = -190e-5;   Yru   =  -499e-5;   Nru   =  -166e-5;
            Xrv   =  798e-5;   Yd    =   278e-5;   Nd    =  -139e-5;
            Xvd   =   93e-5;   Yddd  =   -90e-5;   Nddd  =    45e-5;
            Xuvd  =   93e-5;   Yud   =   556e-5;   Nud   =  -278e-5;
                               Yuud  =   278e-5;   Nuud  =  -139e-5;
                               Yvdd  =    -4e-5;   Nvdd  =    13e-5;
                               Yvvd  =  1190e-5;   Nvvd  =  -489e-5;
                               Y0    =    -4e-5;   N0    =     3e-5;
                               Y0u   =    -8e-5;   N0u   =     6e-5;
                               Y0uu  =    -4e-5;   N0uu  =     3e-5;

    Zw = Xu;
    Zq = Yr;
    Mw = Nv;
    Mq = Nr;

    
    Iy      = Iz; 
    Zwdot   = Xudot;
    Mqdot    = 0; % Added mass in pitch would violate surface cond

            % Masses and moments of inertia
            m11 = m-Xudot;
            % m11 = m11/100; %debug
            m22 = m-Zwdot;
            %m23 = m*xG-Yrdot;
            %m32 = m*xG-Nvdot;
            m33 = Iy-Mqdot;
    %/
            rho = 1023;
            g = 9.81;



    % Mass and Inertia normalization factors
    mnf1 = 1/2 *rho * l1^3;
    inf1 = 1/2 *rho * l1^5;
    mnf2 = 1/2 *rho * l2^3;
    inf2 = 1/2 *rho * l2^5;
    cM = blkdiag( ...
                Hxz(rp1)'*diag([m11*mnf1, m22*mnf1, m33 * inf1])*Hxz(rp1), ...
                Hxz(rp2)'*diag([m11*mnf2, m22*mnf2, m33 * inf2])*Hxz(rp2)     ); 

    Y = [ 1     0       0       0       0;
          0     1       0       0       0;
          0     0       1       0       0;
          1     -tan(delta) 0   tan(delta)  0;
          0     0       0       1       0;
          0     0       0       0       1;];
    M = Y'*cM*Y;
    invM = inv(M);
    
    % De-Normalization. Damping matrix has to be multiplied with 
    % [m/s m/s 1/s]' and result in [kg*m/s^2 kg*m/s^2 kg*m^2/s^2]', with
    % Xu,Zw, Zq, Mw and Mq from GNC being non-dimensional
    U0 = 7.7175; %From GNC
    fnf1 = 1/2 * rho*l1^2*U0; % kg/s
    mnf1 = 1/2 * rho*l1^3*U0; % kg*m/s
    fnf2 = 1/2 * rho*l2^2*U0; % kg/s
    mnf2 = 1/2 * rho*l2^3*U0; % kg*m/s
    
    tD1= -[Xu*fnf1      0            0;
          0             Zw*fnf1      Zq*mnf1;
          0             Mw*mnf1      Mq*mnf1*l1]; 
      
    tD2= -[Xu*fnf2      0            0;
          0             Zw*fnf2      Zq*mnf2;
          0             Mw*mnf2      Mq*mnf2*l2];       
    cD = [ Hxz(rp1)'*tD1 * Hxz(rp1),  zeros(3);
           zeros(3)                ,  Hxz(rp2)'*tD2 * Hxz(rp2)];
    D = Y' *cD * Y;
    
    % The input factor matrix 
    B = [1      1       0;
         0      0       0;
         0      0       0;
         0      0       0;
         0      0       1]; 
    Gamma = -rho*g*[0          0               0                  0            0;
                    0          w1*l1           0                  0            0;
                    0          0               1/3*w1*l1^3            0            0;
                    0          0               0                  w2*l2        0;
                    0          0               0                  0            1/3*w2*l2^3;];
    


    A = [-D * invM, Gamma;
         invM,      zeros(5)];
    Lambda_grave = eye(5); Lambda_grave(4,2) = -1;
    Lambda = blkdiag(eye(5), Lambda_grave);
    % Q = diag([1e10 0 0 0 0 1e10 0 0 1e14 0]); R = diag([1 1 1]); %state
    % number nine is the only one that counts
    Q = diag([1 0 0 0 0 1 0 0 1e17 0]); R = diag([1000 1000 1]); %state number nine is the only one that counts
    % Value of 1e10 because 1 (meter) Q_{1,1} 1 (meter) \approx 
    % 1e5 (Newton) R_{1,1} 1e5 (Newton)
    K = lqr(Lambda * A *inv(Lambda), Lambda*[ B; zeros(5,3)], Q, R); %Note: something was rotten in the state of B

    % Because K is to be multiplied with [p\\ q \right] and not [p\\
    % \breve{q} \right].
    
    K_w_vec=[ 2 1/30 4 1/20]'*.1;

    % Saving everything in a mod structure and returning it
    w = who;
    mod = struct;
    for i=1:length(w)
        mod.( char(w(i)) ) =  eval(char(w(i)));
    end
    save('mod.mat','mod');
end