    function rampvis(x, lramp, u, t)
    % x = state vector
    % lramp = length of the ramp
    % u=input
    % t = time
    persistent fh ah Sm Tm Rm i Fm1 Fm2 th time
    global M mod;
    % Sm = Seabase Model
    % Tm = T-craft Model
    % Rm = Ramp Model
    SLen = mod.l1   ;
    TLen = mod.l2;
    delta = 10/180*pi;
    figurepos  = [100 100 800 200];
    % delta = initial value of the angle of the ramp
    
    if isempty(fh) || ~ishandle(fh)
        i =0;
        fh = figure(1);
        clf(fh);
        set(fh, 'Position', figurepos);
        ah = axes('XLim', [-SLen*1.1, lramp+TLen*1.1], 'YLim', [-15, 20], 'DataAspectRatioMode', 'manual','DataAspectRatio', [1 1 1], 'ydir', 'normal', 'Box', 'on');
        Sm.Vertices = [ 0           0           0;
                        -SLen       0           0;
                        -SLen*0.8   -SLen*0.1   0;
                        0           -SLen*0.1   0;
                        ];
        Sm.Faces = [1 2 3 4 1];
        Sm.FaceColor = [0 0.2 0.6]';
        
        Sm.h = patch('Vertices', Sm.Vertices, 'Faces', Sm.Faces, 'FaceColor', Sm.FaceColor);
        Tm.Vertices = [ 0           0           0;
                        TLen        0           0;
                        TLen        -TLen*0.1   0
                        TLen*0.2    -TLen*0.1   0;
                        ];
        Tm.Faces = [1 2 3 4 1];
        Tm.FaceColor = [0 1 1]';
        Tm.h = patch('Vertices', Tm.Vertices, 'Faces', Tm.Faces, 'FaceColor', Tm.FaceColor);
        
        Rm.Vertices = [0 0 0; 1 1 1];
        Rm.Faces = [1 2];
        Rm.h = patch('Vertices', Rm.Vertices, 'Faces', Rm.Faces);
        

        [x y] = naca5(20, 50, 0.2);
        x = x-1/4;
        Fm.Vertices = [ x' y' zeros(length(x), 1)] * TLen/4;                    
        Fm.Faces = 1:length(x);
        Fm.FaceColor = [1 1 0];
        Fm1 = Fm;
        Fm2 = Fm;
        Fm1.h = patch('Vertices', Fm.Vertices, 'Faces', Fm.Faces,  'FaceColor', Fm1.FaceColor, 'EdgeAlpha', 0.5);
        Fm2.h = patch('Vertices', Fm.Vertices, 'Faces', Fm.Faces,  'FaceColor', Fm2.FaceColor, 'EdgeAlpha', 0.5);

            
        th = text(-150,-30,'Actuation torque: \n hei');
%         

        
        time = 0;
        drawnow;
        
        M = getframe(fh);
    end
    
    %  Refresh if more then N real-time milliseconds since last refresh
    if t - time > 1/15
        time = t;
        
        drawMdl(Sm, x(3), [0, x(2), 0]');
        x2_full = sqrt(lramp^2 - ( -x(4)+x(2) + lramp * sin(delta) )^2);
        drawMdl(Tm, x(5), [x2_full, -lramp * sin(delta)+ x(4), 0]');
        TNose = [x2_full, -lramp * sin(delta)+ x(4), 0]' ;
        drawRamp(Rm, [0, x(2), 0]', TNose);
        angl = u(3)/7e7*10*pi/180;
        drawMdl(Fm1, x(5) + angl,  TNose + fR(x(5))* [TLen/4, -TLen*0.1/2, 0]');
        drawMdl(Fm2, x(5) - angl,  TNose + fR(x(5))* [TLen*3/4, -TLen*0.1/2, 0]');
        set(th, 'String', {['Actuation torque (N \cdot M):' num2str(u(3), 1)], ['Time (sec): ' num2str(t)] });
        i =i+1;
        if abs(i-round(i)) < 0.00001
            i*20;
            i = round(i);
            %M(i) = getframe(fh);
        end
    end
end


function drawMdl(mdl, theta, dispVec)
% Rotates a model with angle theta, displaces it with vector vec and draws
% it
    V = mdl.Vertices;
    V = V*fR(theta)';
    dispMat = ones(1, size(V, 1));
    V = (V' + dispVec*dispMat)';
    set(mdl.h, 'Vertices', V);
end
function drawRamp(mdl,v1, v2)
    set(mdl.h, 'Vertices', [v1'; v2']);
end
    


function R = fR(theta)
    t = theta;
    R = [cos(t) sin(t) 0 
        -sin(t) cos(t) 0;
        0       0      1];
end

function [x2 y2] = naca5(N, k_1, m)
        % http://en.wikipedia.org/wiki/NACA_airfoil
        x = 0:1/N:1;
        I = find(x>=m);
        i = I(1);
        y = zeros(1, length(x));
        y(1:i) = k_1/6 *(  x(1:i).^3 - 3*m*x(1:i).^2 + m^2*(3-m)*x(1:i)  );
        y(i:length(x)) =  k_1 *m^3/6*(1-x(i:length(x)));
        x2 = [x x(length(x):-1:1)];
        y2 = [y -y(length(y):-1:1)];
end